# PatchedPiSettingsRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cloud_video_enabled** | **bool** | Send camera stream to PrintNanny Cloud | [optional] 
**telemetry_enabled** | **bool** | Send telemetry and performance profiling data to PrintNanny Cloud | [optional] 
**pi** | **int** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


